# `configure_dms_viz`

![License](https://img.shields.io/github/license/matsengrp/multidms)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)
[![Ruff](https://img.shields.io/endpoint?url=https://raw.githubusercontent.com/charliermarsh/ruff/main/assets/badge/v2.json)](https://github.com/astral-sh/ruff)

---

`configure_dms_viz` is a python utility that formats your data for the visualization tool [dms-viz](https://dms-viz.github.io/).

For details on how to use `configure_dms_viz`, check out the [documentation](https://dms-viz.github.io/dms-viz-docs/).
